@@ -1,7 +1,9 @@
 class PuppetLint::Plugins::CheckClasses < PuppetLint::CheckPlugin
-  check 'right_to_left_relationship' do
-    tokens.select { |r| r.first == :OUT_EDGE }.each do |token|
-      notify :warning, :message =>  "right-to-left (<-) relationship", :linenumber => token.last[:line]
+  if Puppet::PUPPETVERSION !~ /^0\.2/
+    check 'right_to_left_relationship' do
+      tokens.select { |r| r.first == :OUT_EDGE }.each do |token|
+        notify :warning, :message =>  "right-to-left (<-) relationship", :linenumber => token.last[:line]
+      end
     end
   end
 
@@ -89,7 +91,7 @@ class PuppetLint::Plugins::CheckClasses < PuppetLint::CheckPlugin
   check 'variable_scope' do
     (class_indexes + defined_type_indexes).each do |idx|
       object_tokens = tokens[idx[:start]..idx[:end]]
-      variables_in_scope = ['name', 'title', 'module_name']
+      variables_in_scope = ['name', 'title', 'module_name', 'environment', 'clientcert', 'clientversion', 'servername', 'serverip', 'serverversion', 'caller_module_name']
       referenced_variables = []
       header_end_idx = object_tokens.index { |r| r.first == :LBRACE }
       lparen_idx = object_tokens[0..header_end_idx].index { |r| r.first == :LPAREN }
