@@ -9,8 +9,15 @@ class PuppetLint::Plugins::CheckStrings < PuppetLint::CheckPlugin
     TOKENS.add_tokens("<single quotes string>" => :SSTRING)
     TOKENS.del_token(:SQUOTE)
 
-    TOKENS.add_token :SQUOTE, "'" do |lexer, value|
-      [TOKENS[:SSTRING], lexer.slurpstring(value,["'"],:ignore_invalid_escapes).first ]
+    if Puppet::PUPPETVERSION =~ /^0\.2/
+      TOKENS.add_token :SQUOTE, "'" do |lexer, value|
+        value = lexer.slurpstring(value)
+        [TOKENS[:SSTRING], value]
+      end
+    else
+      TOKENS.add_token :SQUOTE, "'" do |lexer, value|
+        [ TOKENS[:SSTRING], lexer.slurpstring(value,["'"],:ignore_invalid_escapes).first ]
+      end
     end
   end
 
@@ -22,6 +29,10 @@ class PuppetLint::Plugins::CheckStrings < PuppetLint::CheckPlugin
         unless token.last[:value].include? "\t" or token.last[:value].include? "\n"
           notify :warning, :message =>  "double quoted string containing no variables", :linenumber => token.last[:line]
         end
+      elsif token.first == :DQTEXT
+        unless token.last[:value].include? "\\t" or token.last[:value].include? "\\n" or token.last[:value] =~ /[^\\]?\$\{?/
+          notify :warning, :message =>  "double quoted string containing no variables", :linenumber => token.last[:line]
+        end
       end
     end
   end
@@ -37,6 +48,9 @@ class PuppetLint::Plugins::CheckStrings < PuppetLint::CheckPlugin
           end
         end
       end
+      if token.first == :DQTEXT and token.last[:value] =~ /\A\$\{.+\}\Z/
+        notify :warning, :message =>  "string containing only a variable", :linenumber => token.last[:line]
+      end
     end
   end
 
@@ -54,6 +68,8 @@ class PuppetLint::Plugins::CheckStrings < PuppetLint::CheckPlugin
             end
           end
         end
+      elsif token.first == :DQTEXT and token.last[:value] =~ /\$\w+/
+        notify :warning, :message =>  "variable not enclosed in {}", :linenumber => token.last[:line]
       end
     end
   end
